var Immutable = require('immutable');

// Everything in the lists should be lowercase. Potential matches will also
// be converted to lowercase.

var lists = {
  // falsePositivesList should contain only the singular forms of the words,
  // words will be singularized before being checked against this list.
  falsePositives: [
    'rt',
    'http',
    'https',
    'haha',
    'adv',
    'san',
    'tri',
    'asa',
    'att',
    'io',
    'imo',
    'pl',
    'dr',
    'ala',
    'ama',
    'ive'
  ],
  extendedBlacklist: [
    'negro',
    'negroes',
    'chink',
    'chinks',
    'gook',
    'gooks',
    'slant-eye',
    'slant-eyes',
    'slanty-eye',
    'slanty-eyes',
    'nigger',
    'niggers',
    'nigga',
    'niggas',
    'spic',
    'spics',
    'rape',
    'rapes',
    'rapist',
    'rapists',
    'raping',
    'bombing',
    'bombings',
    'shootings',
    'shooting',
    'shooter',
    'miscarriage',
    'miscarriages',
    'coon',
    'coons',
    // Up to the user to distinguish between respectful use
    // of 'transgender' as adjective (more likely now?) and
    // insulting use as noun.
    //'transgender',
    'transgenders', // OK normally, not OK as a noun.
    'swastika',
    'swastikas',
    'nazi',
    'nazis',
    'supremacy',
    'supremacist',
    'supremacists',
    'white-supremacist',
    'white-supremacists',
    'nazidom',
    'nazism',
    'naziism',
    'nazisms',
    'naziisms',
    'stormer',
    'stormers',
    'terrorist',
    'terrorists',
    'holocaust',
    'islamist',
    'islamists',
    'jihadist',
    'jihadists',
    'klan',
    'klans',
    'blackface',
    'blackfaces',
    'abuser',
    'abusers',
    'n-word',
    'n-words',
    'darky',
    'darkies',
    'wigger',
    'wiggers',
    'crip',
    'crips',
    'cripple',
    'cripples',
    'pedophile',
    'pedophiles',
    'pedophilia',
    'cancer',
    'cancers',
    'seizure',
    'seizures',
    'eulogy',
    'eulogies',
    'lynching',
    'lynchings',
    'slaveowner',
    'slaveowners',
    'condolence',
    'condolences',
    'RIP',
    'molestation',
    'molestations',
    'molester',
    'molesters',
    'triggering',
    'trigger',
    'brownface',
    'niggaz',
    'harelip',
    'harelips',
    'invalid',
    'invalids',
    'moron',
    'morons',
    'spaz',
    'spazzes',
    'pedo',
    'pedos',
    'negress',
    'blackamoor',
    'towelhead',
    'towelheads',
    'muzzy',
    'muzzie',
    'muzzies',
    'boylove',
    'childlove',
    'boylovers',
    'childlovers',
    'qanon',
    'qanons',
    'gaza',
    'israel',
    'genocide',
    'explosion',
    'assault',
    'hamas',
    'palestine',
    'suicide',
    'idf',
    'isis',
    'mourner',
    'mourners',
    'iraq',
    'ebola',
    'asphyxiation',
    'ferguson',
    'beheading',
    'gun',
    'guns',
    'rifle',
    'rifles',
    'gunshot',
    'gunshots',
    'gunfire',
    'semiautomatic',
    'semiautomatics',
    'automatic',
    'automatics',
    'silencer',
    'silencers',
    'firearm',
    'firearms',
    'bloodshed',
    'garner',
    'torture',
    'torturer',
    'torturing',
    'jihad',
    'grieving',
    'victim',
    'dylann',
    'arson',
    'firebombing',
    'killed',
    'gunmen',
    'gunman',
    'casualties',
    'casualty',
    'sniper',
    'antisemitism',
    'anti-semitism',
    'antisemite',
    'antisemites',
    'anti-semite',
    'anti-semites',
    'tomahawk',
    'tomahawks',
    'cville',
    'charlottesville',
    'heyer',
    'parkland',
    'cruz',
    'stoneman',
    'broward',
    'lockdown',
    'aids',
    'hiv',
    'hiv/aids',
    'niglet',
    'niglets'
  ],
  tragedyModeBlacklist: [
    'invasion',
    'horror',
    'bomb',
    'plane',
    'death',
    'missile',
    'crash',
    'airstrike',
    'brigadier',
    'accident',
    'depression',
    'foley',
    'rip',
    'chokehold',
    'coroner',
    'eric',
    'ukraine',
    'donetsk',
    'walter',
    'scott',
    'cop',
    'police',
    'officer',
    'nepal',
    'earthquake',
    'katmandu',
    'Durbar',
    'wreckage',
    'carnage',
    'riot',
    'rioting',
    'baltimore',
    'freddie',
    'gray',
    'derailment',
    'amtrak',
    'train',
    'philadelphia',

    'rev',
    // 'sharonda',
    // 'coleman',
    'singleton',

    // 'cynthia',
    'hurd',

    // 'susie',
    // 'jackson',

    // 'ethel',
    // 'lance',

    // 'depayne',
    // 'middleton',
    // 'doctor',

    // 'clementa',
    // 'pinckney',

    // 'tywanza',
    // 'sanders',
    'sander',

    // 'daniel',
    // 'simmons',
    // 'simmon',

    // 'myra',
    // 'thompson',

    'ame',
    'emanuel',
    'charleston',
    'columbia',
    'racist',
    'supremacist',
    'racism',
    'supremacy',
    'roof',
    'murder',
    'murderer',
    'whiteness',
    'rhodesian',
    'rhodesia',
    'funeral',

    // 'cameraman',
    // 'virginia',
    // 'inland',

    // 'brussel',
    // 'brussels',

    // 'orlando',
    // 'pulse',
    // 'nightclub',
    // 'mateen',
    // 'omar',

    // 'dallas',

    // 'baton',
    // 'rouge'
    // 'chelsea',
    // 'manhattan',
    'blast',

    'missile',
    'missiles',
    'syria',
    'syrian',
    'syrians',

    // 'manchester',
    // 'ariana',
    // 'grande',

    // 'borough',
    // 'vauxhall',

    // 'acid',
    // 'khan'
    'uva',
    'virginia',
    'torch',
    'torches',
    'percenter',
    'tiki',
    'driver',
    'heather',
    // 'field',
    // 'barcelona',
    // 'spain',
    // 'ramblas',
    // 'van',
    // 'catalonia',
    // 'catalonian',
    // 'catalonians',
    // 'houston',
    'flood',
    'floods',
    'storm',
    'storms',
    'hurricane',
    'hurricanes',
    'tornado',
    'tornadoes',
    'tornados',

    'church',
    'churches',

    'classmate',
    'classmates',
    'school',
    'schools'
  ],
  whitelist: []
};

// TODO: Differentiate between words not cool to say vs. words not cool to
// respond to.

module.exports = Immutable.Map(lists);
